package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.UserCoupon;

/**
 * 优惠卷发放Service接口
 * 
 * @author ruoyi
 * @date 2023-11-07
 */
public interface IUserCouponService 
{
    /**
     * 查询优惠卷发放
     * 
     * @param cuId 优惠卷发放主键
     * @return 优惠卷发放
     */
    public UserCoupon selectUserCouponByCuId(Long cuId);

    /**
     * 查询优惠卷发放列表
     * 
     * @param userCoupon 优惠卷发放
     * @return 优惠卷发放集合
     */
    public List<UserCoupon> selectUserCouponList(UserCoupon userCoupon);

    /**
     * 新增优惠卷发放
     * 
     * @param userCoupon 优惠卷发放
     * @return 结果
     */
    public int insertUserCoupon(UserCoupon userCoupon);

    /**
     * 修改优惠卷发放
     * 
     * @param userCoupon 优惠卷发放
     * @return 结果
     */
    public int updateUserCoupon(UserCoupon userCoupon);

    /**
     * 批量删除优惠卷发放
     * 
     * @param cuIds 需要删除的优惠卷发放主键集合
     * @return 结果
     */
    public int deleteUserCouponByCuIds(Long[] cuIds);

    /**
     * 删除优惠卷发放信息
     * 
     * @param cuId 优惠卷发放主键
     * @return 结果
     */
    public int deleteUserCouponByCuId(Long cuId);
}
